CrdtSchemaRegistry class

Manages the CRDT schema for a database.

Constructors

CrdtSchemaRegistry(DatabaseSession _session, {required List<Table> syncTables, Iterable<TableDefinition>? tableDefinitions})
Creates a new instance of CrdtSchemaRegistry.

Properties

hashCode → int
The hash code for this object.
no setterinherited
registryChanged → bool
Whether the last syncAndGetSchema call inserted, updated, or deleted registry rows.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncTables → List<Table>
The list of tables to sync with CRDT.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncAndGetSchema() → Future<(List<CrdtSchemaTable>, List<CrdtSchemaColumn>)>
Ensures that the CRDT schema is created for the database.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited