CrdtScopeNodeRepository class

Properties

attachRow CrdtScopeNodeAttachRowRepository
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<CrdtScopeNodeTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<CrdtScopeNode> rows, {OrderByBuilder<CrdtScopeNodeTable>? orderBy, OrderByListBuilder<CrdtScopeNodeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScopeNode>>
Deletes all CrdtScopeNodes in the list and returns the deleted rows.
deleteRow(DatabaseSession session, CrdtScopeNode row, {Transaction? transaction}) Future<CrdtScopeNode>
Deletes a single CrdtScopeNode.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<CrdtScopeNodeTable> where, OrderByBuilder<CrdtScopeNodeTable>? orderBy, OrderByListBuilder<CrdtScopeNodeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScopeNode>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<CrdtScopeNodeTable>? where, int? limit, int? offset, OrderByBuilder<CrdtScopeNodeTable>? orderBy, OrderByListBuilder<CrdtScopeNodeTable>? orderByList, Transaction? transaction, CrdtScopeNodeInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<CrdtScopeNode>>
Returns a list of CrdtScopeNodes matching the given query parameters.
findById(DatabaseSession session, int id, {Transaction? transaction, CrdtScopeNodeInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<CrdtScopeNode?>
Finds a single CrdtScopeNode by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<CrdtScopeNodeTable>? where, int? offset, OrderByBuilder<CrdtScopeNodeTable>? orderBy, OrderByListBuilder<CrdtScopeNodeTable>? orderByList, Transaction? transaction, CrdtScopeNodeInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<CrdtScopeNode?>
Returns the first matching CrdtScopeNode matching the given query parameters.
insert(DatabaseSession session, List<CrdtScopeNode> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false}) Future<List<CrdtScopeNode>>
Inserts all CrdtScopeNodes in the list and returns the inserted rows.
insertRow(DatabaseSession session, CrdtScopeNode row, {Transaction? transaction}) Future<CrdtScopeNode>
Inserts a single CrdtScopeNode and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<CrdtScopeNodeTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _isd.LockBehavior.wait}) Future<void>
Acquires row-level locks on CrdtScopeNode rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<CrdtScopeNode> rows, {ColumnSelections<CrdtScopeNodeTable>? columns, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScopeNode>>
Updates all CrdtScopeNodes in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<CrdtScopeNodeUpdateTable> columnValues, Transaction? transaction}) Future<CrdtScopeNode?>
Updates a single CrdtScopeNode by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, CrdtScopeNode row, {ColumnSelections<CrdtScopeNodeTable>? columns, Transaction? transaction}) Future<CrdtScopeNode>
Updates a single CrdtScopeNode. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<CrdtScopeNodeUpdateTable> columnValues, required WhereExpressionBuilder<CrdtScopeNodeTable> where, int? limit, int? offset, OrderByBuilder<CrdtScopeNodeTable>? orderBy, OrderByListBuilder<CrdtScopeNodeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScopeNode>>
Updates all CrdtScopeNodes matching the where expression with the specified columnValues. Returns the list of updated rows.
upsert(DatabaseSession session, List<CrdtScopeNode> rows, {required ColumnSelections<CrdtScopeNodeTable> conflictColumns, ColumnSelections<CrdtScopeNodeTable>? updateColumns, WhereExpressionBuilder<CrdtScopeNodeTable>? updateWhere, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScopeNode>>
Upserts all CrdtScopeNodes in the list and returns the resulting rows.
upsertRow(DatabaseSession session, CrdtScopeNode row, {required ColumnSelections<CrdtScopeNodeTable> conflictColumns, ColumnSelections<CrdtScopeNodeTable>? updateColumns, WhereExpressionBuilder<CrdtScopeNodeTable>? updateWhere, Transaction? transaction}) Future<CrdtScopeNode?>
Upserts a single CrdtScopeNode and returns the resulting row.

Operators

operator ==(Object other) bool
The equality operator.
inherited