count method

Future<int> count(
  1. DatabaseSession session, {
  2. WhereExpressionBuilder<CrdtScopeNodeTable>? where,
  3. int? limit,
  4. Transaction? transaction,
})

Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.

Implementation

Future<int> count(
  _isd.DatabaseSession session, {
  _isd.WhereExpressionBuilder<CrdtScopeNodeTable>? where,
  int? limit,
  _isd.Transaction? transaction,
}) async {
  return session.db.count<CrdtScopeNode>(
    where: where?.call(CrdtScopeNode.t),
    limit: limit,
    transaction: transaction,
  );
}