serverpod_offline_sync library

Classes

BaseHlc
Base class for HLC timestamps.
Hlc
A Hybrid Logical Clock implementation that supports both ISO 8601 and Unix timestamp formats. The datetime component has millisecond precision and is always stored in UTC.
Protocol

Extensions

BaseHlcToHlc on BaseHlc
Extensions for BaseHlc to convert it to an Hlc.
HlcMax on Iterable<Hlc>
Extensions for an Iterable of Hlc.

Exceptions / Errors

ClockDriftException
Exception thrown when the clock drift exceeds the maximum allowed.
DuplicateNodeException
Exception thrown when a duplicate node is detected.
OverflowException
Exception thrown when the timestamp counter overflows.