CrdtDatabaseSession class
Wraps a DatabaseSession to provide a CrdtDatabase as DatabaseSession.db.
- Available extensions
Constructors
-
CrdtDatabaseSession(Database db, {required List<
Table> syncTables, CrdtDatabaseContext? context, int syncBatchSize = CrdtSync.defaultSyncBatchSize, Duration continuousSyncInterval = CrdtSync.defaultContinuousSyncInterval, UuidValue? persistentUserId}) - Creates a CrdtDatabaseSession instance.
-
CrdtDatabaseSession.wraps(DatabaseSession session, {required List<
Table> syncTables, CrdtDatabaseContext? context, int syncBatchSize = CrdtSync.defaultSyncBatchSize, Duration continuousSyncInterval = CrdtSync.defaultContinuousSyncInterval, UuidValue? persistentUserId}) -
Creates a CrdtDatabaseSession instance that wraps a
DatabaseSession.factory
Properties
- crdtDb → CrdtDatabase
-
Available on DatabaseSession, provided by the CrdtDatabaseAccess extension
Returns the wrapped CrdtDatabase for this session.no setter - db → CrdtDatabase
-
The database to access.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- logQuery → LogQueryFunction?
-
Optional function to log a query.
no setter
- logWarning → LogWarningFunction?
-
Optional function to log a warning during the execution of a query.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction ↔ Transaction?
-
Optional transaction to use for all database queries.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited