CrdtSchemaColumn class abstract
CRDT schema columns table.
Constructors
- CrdtSchemaColumn({int? id, required int tblId, CrdtSchemaTable? tbl, required String name})
-
factory
-
CrdtSchemaColumn.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The id column of the row. Can be null if this row is not yet stored in
the database.
getter/setter pair
- name ↔ String
-
Name of the column.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
table
→ Table<
int?> -
The table that this row belongs to.
no setter
- tbl ↔ CrdtSchemaTable?
-
Reference to the table this column belongs to.
getter/setter pair
- tblId ↔ int
-
getter/setter pair
Methods
-
copyWith(
{int? id, int? tblId, CrdtSchemaTable? tbl, String? name}) → CrdtSchemaColumn - Returns a shallow copy of this CrdtSchemaColumn with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toJsonForProtocol(
) → Map< String, dynamic> - Returns a JSON structure of the model, optimized for Protocol communication.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- t → CrdtSchemaColumnTable
-
final
Static Methods
-
include(
{CrdtSchemaTableInclude? tbl}) → CrdtSchemaColumnInclude -
includeList(
{WhereExpressionBuilder< CrdtSchemaColumnTable> ? where, int? limit, int? offset, OrderByBuilder<CrdtSchemaColumnTable> ? orderBy, OrderByListBuilder<CrdtSchemaColumnTable> ? orderByList, CrdtSchemaColumnInclude? include}) → CrdtSchemaColumnIncludeList
Constants
- db → const CrdtSchemaColumnRepository