CrdtScopeAttachRepository class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nodes(
DatabaseSession session, CrdtScope crdtScope, List< CrdtScopeNode> crdtScopeNode, {Transaction? transaction}) → Future<void> -
Creates a relation between this CrdtScope and the given CrdtScopeNodes
by setting each CrdtScopeNode's foreign key
scopeIdto refer to this CrdtScope. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited